package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````"`!0````!$``5(````#0``0)4```````T`"``
M"``H`!P`&P````8````T$```-!```#0```$````!``````4````$`````P``
M`300``$T$``!-`````T````-````!`````$````!`````!`````0``````"0
MX```D.`````%``$```````$``/[8$`'^V!`!_M@```(\```2@`````8``0``
M`````@``_O`0`?[P$`'^\````0````$`````!@````0````$```!1!```400
M``%$````1````$0````$````!&1TY5$`````````````````````````````
M``8````09'3E4@``_M@0`?[8$`'^V````2@```$H````!`````$O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````"````!@```"`````$
M````%`````-'3E4`HIB3O(4!/GQL:?'YIV,YSM"3`V<````1````0@````@`
M```(!!`<`(($0"4`0``XB`&&H`(``<`I!"A+1S*B.`@,!(H```!"````0P``
M`$<```!+````3````%,```!5````5P```%L```!=`````````%\```!B````
M8P```&0``````````&M*\'L?W\5N#N_3ZBU'WLY\FG]KMIO%+@[D_R`.\8VX
M?-1DU1Q8<=D!QD?BP.-+K!W3V_)\DN.Z+#_EPF!LH?IOBP&SUD,):H&<^8=`
MG+G$9LRO9QR+\CCLU45"TW`'B)`%B<6>XA0,<;+5R9[CS=KMVV(S"Y<Z#):;
MI%9KH]VGFYRI?PH"I^%7$(H*2?O@HP````````````````````````*U````
M```````2```````#6P``````````$@```````?(``````````!(````````1
M```````````@```````#R0``````````$@```````TP``````````!(`````
M``$9```````````2```````"T```````````$@```````+P``````````!(`
M``````*\```````````2````````F```````````$@```````10`````````
M`!(```````)L```````````2```````#"0``````````$@```````GT`````
M`````!(```````%O```````````2```````#&0``````````$@```````Q``
M`````````!(```````$]```````````2````````R@``````````$@``````
M`;D``````````!(```````([```````````2```````!Z@``````````$@``
M`````ID``````````!(```````&F```````````2```````"B@``````````
M$@```````;(``````````!(```````%+```````````2```````#(```````
M````$@```````"T``````````"````````)-```````````2```````#+0``
M````````$@```````'@``````````!(```````*G```````````2```````#
M8@``````````$@```````>,``````````!(```````,^```````````2````
M````IP``````````$@```````60``````````!(```````*N```````````2
M```````"A```````````$@```````EH``````````!(```````(+````````
M```2```````"D@``````````$@```````&H``````````!(```````$>````
M```````2```````"UP``````````$@```````9L``````````!(```````+"
M```````````2````````^```````````$@```````U0``````````!(`````
M``*@```````````2```````!?0``````````$@```````#P``````````"``
M``````#<```````````2```````!6P``````````$@```````S0`````````
M`!(```````!0```````````@```````"4@``````````$@```````O@`````
M`````!(```````'W```````````2```````"Y0``````````$@```````AP`
M`````````!(```````)C```````````2```````"\```````````$@``````
M`8L0`$H0`````!(```````/2$`!'<````-@2```,```#H!``3N``````$@``
M#0```_<0`#?````++!(```P```-O$``2P````F`2```,```#IA``+A`````,
M$@``#```!%80`"X@```"B!(```P```10$``2;``````2```+```$@Q``0O``
M``2`$@``#````X40`@$4`````!```!D```/>$``PL````%02```,```"+!``
M3QP````$$0``#@```<00`@$P````$Q$``!D```.1$`(16``````0```9```$
M3A``+*````!`$@``#```!&,0`#8@```!G!(```P```1U$``U,````+`2```,
M```$!!`"`00`````$```%P```(<0`$SP`````!(```````-T$`(!(`````01
M```9```#ZQ``,1````'($@``#````P(0`@$D````!!$``!D```-^$`(!%```
M```0```8```$-Q`"`1`````$$0``&````W40`@$@````!"$``!D```.6$`!)
M@`````02```,```!*A``3#``````$@``````!"<0`$C`````P!(```P```0*
M$``5(````"02```,```$!A`"`00`````(```%P```0D0`@$H````!!$``!D`
M``-V$`(!(`````0A```9```#MQ``->`````X$@``#```!!$0`"U`````S!(`
M``P```#K$`(!+`````$1```9```$01``,N````)($@``#`!L:6)P97)L+G-O
M+C4N,C(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R
M=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F54
M86)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K
M7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R
M;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?
M9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S
M971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L
M7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H
M<F5A9%]G971S<&5C:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N
M<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T
M<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI
M;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`
M;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R
M96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R
M=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U
M<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M
M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C
M=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A
M<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB
M<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"
M0U\R+C(`1TQ)0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#
M7S(N-````````@`"``,````"``(``@`"`````@``````!``"``(````"``(`
M````````!0`&``(````"``(````'`````@`"`````@`"``8`!````````@`"
M``(``P`"```````'````!`````(``@````````````@````"``@``P`(``,`
M`@`"`````0`!``$``0`!``$``0`!``$``0`!`````0`!``$``0`!`````@`!
M``(``0`!``(``0````$``0`!`````@`!``$````!``$``@```=,````0````
M,`UI:1(````&```$F0```!`-:6D0`````P``!*,```````$`!0```B(````0
M``````UI:1(````(```$F0```!`):1ET````!P``!*T````0"6D9<@````4`
M``2Y````$`UI:10````$```$Q0```!`-:6D0`````@``!*,`````$`'_\```
M'A0`````$`(!(```51,`````$`(!)```5Q,`````$`(!*```8!,`````$`(!
M+```9!,`````$`(!,```3A,`````$`(``````14`````$`(`!````A4`````
M$`(`"````Q4`````$`(`#```!14`````$`(`$```!A4`````$`(`%```!Q4`
M````$`(`&```"!4`````$`(`'```"14`````$`(`(```0A4`````$`(`)```
M"A4`````$`(`*```"Q4`````$`(`+```#!4`````$`(`,```#14`````$`(`
M-```#A4`````$`(`.```#Q4`````$`(`/```$!4`````$`(`0```$14`````
M$`(`1```$A4`````$`(`2```$Q4`````$`(`3```%!4`````$`(`4```%14`
M````$`(`5```%A4`````$`(`6```%Q4`````$`(`7```&!4`````$`(`8```
M&14`````$`(`9```&A4`````$`(`:```&Q4`````$`(`;```'!4`````$`(`
M<```'14`````$`(`=```'A4`````$`(`>```'Q4`````$`(`?```(!4`````
M$`(`@```(14`````$`(`A```(A4`````$`(`B```(Q4`````$`(`C```)!4`
M````$`(`D```)14`````$`(`E```)A4`````$`(`F```)Q4`````$`(`G```
M*!4`````$`(`H```*14`````$`(`I```*A4`````$`(`J```7!4`````$`(`
MK```*Q4`````$`(`L```+!4`````$`(`M```+14`````$`(`N```+A4`````
M$`(`O```+Q4`````$`(`P```,!4`````$`(`Q```,14`````$`(`R```,A4`
M````$`(`S```,Q4`````$`(`T```-!4`````$`(`U```-14`````$`(`V```
M5!4`````$`(`W```-Q4`````$`(`X```.!4`````$`(`Y```.14`````$`(`
MZ```.Q4`````$`(`[```/!4`````$`(`\```/14`````$`(`]```/A4`````
M$`(`^```/Q4`````$`(`_```0!4`````$`(!````014`````E"'_\'P(`J:0
M`0`4D\$`"$*?``5_R`*F/]X``CO>[72`'O_\+X```$&^``A(`#C)@`$`%'P(
M`Z:#P0`(."$`$$Z``"``````````````````````E"'_P'P(`J:3P0`XD`$`
M1)/A`#R080`<D($`&)"A`!0X@0`8.*$`%#AA`!P_X!`"@2*/^)$A`"PY(```
M2``XE3R@$``XI4PP/&`0`'RD*W@X8TSP2``U/3T@$`*+R0$L+YX``$">`"Q(
M`#>I/4`0`B^#``"0:A%409X!X#_@$`)(`#;Q@'\!*$@`.@F;PP=E@'\!*$@`
M.?V)(P3V?&H;>(!_`2AA*0`"F2H$]D@`.>6!(0`</4`__V%*__\Y*0`%B0,$
M]G^)4$!A"@`!F4,$]D&=`415(Q`Z/^`0`D@`-W6!00`8@*$`'#T`$`([_P%$
M@0@!$($J```OA0`!?&L;>)!_$`B1`P`(D2,``#T@$``Y*5*PD2,`!#T@$``Y
M*5*TD2,`##D@``21/Q`$0)T`,%2I$#HY`P`,.2G_^%4I\+XY*0`!?2D#IF``
M``!@````A2H`!)4H``1"`/_X5*D0.H!_$!`\@!``.2D`##E````XX```?69;
M>#BE``,XA"S@?4M)+D@`.$U\?AMY08(`9(!_$!!(`#8M/&`0`#B!`"@X8U!@
M3,8Q@D@`$`DO@P``09X`4(!_$!!(`#7)2``WY7_#\WB!00`L@2*/^'U*2GDY
M(```0((`@(`!`$2#P0`X@^$`/#@A`$!\"`.F3H``((!_$!!(`#A=?'X;>$O_
M_Y2`?Q`,+X,``$&>`"1(`#*E2___I#R`$`(\8!``.(0!,#AC48Q,QC&"2``V
M^3Q@$``X@0`H.&-/_$S&,8)(``]U+X,``)!_$`Q!GO]L2``R94O__V1(`#4]
M.&```4@`-E5\*0MX5"$`-C@```"4(?_P?`@#II`!```]`!``A:A/#$@`-G``
M```````````````](!`"/&`0`CDI`1`X8P$0.2D``WTC2%`KB0`&3)T`(#T@
M```Y*0``+XD``$V>`"!]*0.F3H`$(&````!@````/&`0`CR`$`(X8P$0.(0!
M$'R#(%!\A!9P?(0.<'R$`95-@@`@/4```#E*```OB@``39X`('U)`Z9.@`0@
M8````)0A__!\"`*FD^$`##_@$`*)/P%#D`$`%"^)``!`G@`02___83D@``&9
M/P%#@`$`%(/A``PX(0`0?`@#IDZ``"`](!`".2G^X'TC2WB!(P``+XD``$">
M``Q+__]H8````#T@```Y*0``+XD``$&>_^R4(?_P?`@"IGTI`Z:0`0`43H`$
M(8`!`!0X(0`0?`@#IDO__S``````````````````````````````````````
ME"']0#E#`#!\"`*F.0```)`!`L23(0*DDT$"J)-A`JR3@0*PDZ$"M)/!`KB3
MX0*\.2$`&(#BC_B0X0*<..```#C@``A\Z0.F2```&&````!@````8````&``
M``!@````A,H`")$)``"1"0`(@.H`!)#)``0Y*0`0D.G__$(`_^0Y(`!`..$`
M>'TI`Z8X````A,<`"($'``2!)__8@4?_W(%G_ZB`A_^L?,9*>("G_YA]"E)X
M@2?_G'S(6GA]2B)X?0@J>'U)2GA5"@@\52D(/I`'`!A]*5-XD2<`'$(`_[2`
MPP`4@`,`!#U`6H*`@P`<@6,`#&%*>9F#PP``@*,`)%0(*#Z!(P`(@.$`'%5\
M\#Y\WR)X5]TH-'__6#B#80`L52GP`GSE.!1_G$MX?.=0%($A`"1]".MX?_\B
M>'T(.!1\Q^)X?^CX%%?>\`)\Z``X?21(%%0'\#Y]*5`4?/[S>'T(,GA7YR@^
M?2E`%'^(\GA]*3@4@.$`-'T(^#A_9M@45_WP/GT(XGA_^U`453HH/G_H^!1_
MR.IX?__0%'T(2#A\YU`453OP/H$A`#Q\Y^`4?0CR>'T(.!1_O-IX5^PH/G^<
M^#A]B&`4?.E0%($A`$17^O`^?YSJ>'SG\!1_:-)X?.?@%%6<*#Y_A^`4?0A@
M.'_)4!15C/`^@2$`3'_>Z!1]'=IX?][H%']'8GA7G2@^?.?@.'^^Z!1]"5`4
M@2$`5%>9\#Y]"-@4?/S2>'V'RGA]".`45[PH/G^(X!1\Z.@X?^E0%%>[\#Z!
M(0!<?1UB>'__T!1__^@4?RC:>%>=*#Y]".`X?[_H%'SI4!2!(0!D5YKP/GSG
M8!1]',IX?VC2>'SGX!17O"@^?X?@%'T(Z#A_R5`45ZSP/H$A`&Q]'=IX?][(
M%'_>Z!1_1V)X5YTH/GSGX#A_ON@4?0E0%($A`'17F?`^?0C8%'S\TGA]A\IX
M?0C@%%>\*#Y_B.`4?.CH.'_I4!17N_`^@2$`?'T=8GA__]`4?__H%'\HVGA7
MG2@^?0C@.'^_Z!1\Z5`4@2$`A%>:\#Y\YV`4?1S*>']HTGA\Y^`45[PH/G^'
MX!1]".@X?\E0%%>L\#Z!(0",?1W:>'_>R!1_2&)X?][H%%>=*#Y_ON@4?1[@
M.'T)4!17G/`^@2$`E'_>TGA]"-@4?8?B>'T(\!17OB@^5[OP/G_(\!1\Z.@X
M?^E0%'T(8GB!(0"<?__0%%?'*#Y__T`4?XC:>'__.!1]"/`X?.E0%'T(XGA7
MR?`^?.=@%(/!`*1_?4IX?.=`%%?H*#Y_O?@X?.=`%'_>4!2!`0"L5^SP/G^>
MX!1_O]IX?3YB>'_\^!14_2@^?[_H%'_?.#A]"%`45/SP/H#A`+1__TIX?0C8
M%%>^*#Y]"/@4?9_B>'T(\!2#P0"\?__H.'U'4!1]*D@4?^=B>(/A`,0]0&[9
M5[WP/F%*ZZ%]*3@450<H/GTI.!1_A^IX?]Y0%'_>8!1\[$)X@.$`S%4(\#Y_
MWF`452PH/GV>8!1_OD)X?_]0%'__X!1_W$IX@\$`U%4I\#Y__^`459PH/G^?
MX!1]'TIX?.=0%'__8GA\Y^@458SP/GSG^!17GR@^?.?X%'T]8GB#X0#<?]Y0
M%'^]XGA_WD`45XCP/G_>Z!14_2@^?[[H%'V<0GB#P0#D@V$!7'__4!2#(0%L
M?3](%'^?.GA_Z?@45.?P/E>\*#Y]"3IX?Y_@%'_>4!2#X0#L?9Y@%'T^ZGA_
MS/`45ZGP/E>,*#Y\_4IX?9Y@%'__4!2#P0#T?[WB>'__0!1__^@45XCP/E6=
M*#Y]/$)X?[_H%'_>4!2#X0#\?/XX%'^>8GA\Y_`458SP/E>^*#Y]'&)X?.?P
M%'__4!2#P0$$?YSJ>'__2!1__^`45ZGP/E3\*#Y]G4IX?Y_@%'_>4!2#X0$,
M?1Y`%'^^.GA_R/`45.?P/E>=*#Y]*#IX?[[H%'__4!2#P0$4?9]@%'T?XGA_
M[/@45XCP/E>L*#Y\_$)X?9]@%'_>4!2#X0$<?YSJ>'_>2!1_WN`45ZGP/E6<
M*#Y]'4IX?Y[@%'__4!2#P0$D?/\X%'^_8GA_Y_@458SP/E>=*#Y])V)X?[_H
M%'_>4!2#X0$L?1Y`%'S^XGA_R/`45X?P/E>\*#Y]B#IX?Y[@%'__4!2#P0$T
M?3](%'T?ZGA_Z?@45ZCP/E>=*#Y\Z4)X?[_H%'_>4!2#X0$\?9Y@%'T^XGA_
MS/`45XGP/H&!`417O"@^?][@%'T<2GA__U`4?/\X%'^?ZGA\Y_@45[WP/E??
M*#Y]/.IX?^?X%'V,4!2`X0%,?0Q`%'^,\GA]"&`45][P/E?L*#Y_O/)X?8A@
M%'SG4!2!`0%4?.=(%'^)^GA\YT@45__P/E6)*#Y_VOIX?.=(%'U(4!15G/`^
M?2KH%'],8G@]0(\;84J\W%3]*#Y_Z.-X?2E@%'TIZ!1_^N`X@Z$!9']JV!1]
M"#@X?0C3>%3G\#Z#00%T?]OP%%4[*#Y_R/`4?X@[>'_>V!1]"$@X?YLX.'^J
MZ!15*?`^?0C;>'_]^!17W2@^?^CX%'SH2WA_O^@4?0CP.'S_2#A_*L@45]OP
M/GT(^WA_^>`45[XH/H.!`7Q_Z/@4?2C;>'_?\!1].=@X?^K0%'T(Z#B#00&$
M5[WP/GT(RWA\_S@45]\H/GSH.!1_:.MX?^?X%']YZ#A\ZN`4?0CP.'TG2!17
MWO`^?0C+>%?G*#Z#(0&,?0A(%'^I\WA\Z#@4?2GX.'^H\#A_2M`45_SP/GTI
M0WA]&M@45/\H/H-!`91]"4`4?\GC>'_H^!1]*3@X?\C@.'\JR!14^_`^?[GH
M%(,A`9Q]*4-X5^<H/GT)Z!1_B=MX?.@X%'TI^#A_B-@X?TK0%%?]\#Y_VO`4
M@T$!I'TI0WA4_R@^?0GP%']IZWA_Z/@4?2DX.']HZ#A_*L@45/[P/GTI0WA]
M&>`45^<H/H,A`:Q]"4`4?ZGS>'SH.!1]*?@X?ZCP.']*T!17_/`^?2E#>'T:
MV!14_R@^@T$!M'T)0!1_R>-X?^CX%'TI.#A_R.`X?RK(%%3[\#Y]*4-X?1GH
M%%?G*#Z#(0&\?0E`%'^)VWA\Z#@4?2GX.'^(V#A_2M`45_WP/GTI0WA]&O`4
M5/\H/H-!`<1]"4`4?VGK>'_H^!1]*3@X?VCH.'\JR!14_O`^?2E#>'T9X!17
MYR@^@R$!S'T)0!1_J?-X?.@X%'TI^#A_J/`X?TK0%%?\\#Y]*4-X?1K8%%3_
M*#Z#00'4?0E`%'_)XWA_Z/@4?2DX.'_(X#A_*L@45/OP/GTI0WA]&>@45^<H
M/H.A`=Q]"4`4?XG;>'SH.!1]*?@X?XC8.']*T!17__`^?2E#>'T:\!14_B@^
M@T$!Y'T)0!1_:?MX?0CP%']Y^#A_RN@4?2DX.'_>X!14Y_`^?2G+>%4=*#Y]
M*?`4?_X[>'TIZ!1_^3@X@Z$![']*T!1_WD`X51SP/G]ZV!1_R,MX?/G@.'_(
MV!1\Z.-X53LH/GT(2#A_?M@4?\KH%(.A`?15.O`^?_[X%'T)RWA7?B@^?0GX
M%'^)TWA_R/`4?2G8.($!`@1_G]`X?4KH%(.A`?Q]/_MX?4HX%#T@RF)7>_`^
M82G!UGU?4!17WR@^?T?:>'_J^!1]2>@4?.?R>'U*X!2#@0(45][P/GU*.!17
MYR@^?WWR>'U*.!1]"4`4@.$"#'^]^GA]"-`45__P/GT(Z!1572@^?0CH%'_=
M^GA\Z3@4?[U2>'SGV!152O`^?.?H%%4=*#Y\Y^@4?_M2>(.A`AQ_B>`4?]SP
M%']\0GA_WN`450CP/E3\*#Y]6T)X?][@%'^IZ!2#@0(D?_WX%']].GA__^@4
M5.?P/E?=*#Y]&SIX?__H%'^)X!2#H0(L?5Q0%']\\GA]2N`45][P/E?\*#Y\
M^_)X?4K@%'^IZ!2#@0(T?1U`%']]^GA]".@45__P/E5=*#Y_V_IX?0CH%'^)
MX!2#H0(\?/PX%']\4GA\Y^`454KP/E4<*#Y_^U)X?.?@%'^IZ!2#@0)$?]WP
M%']]0GA_WN@450CP/E3]*#Y]6T)X?][H%'^)X!2#H0),?_SX%']\.GA__^`4
M5.?P/E?<*#Y]&SIX?__@%'^IZ!2#@0)4?5U0%']]\GA]2N@45][P/E?]*#Y\
M^_)X?4KH%'^)X!2#H0)<?1Q`%']\^GA]".`45__P/E5<*#Y_V_IX?XC@%'^I
MZ!2!`0)D?/TX%']]4GA\Y^@454KP/E>=*#Y_^U)X?Z?H%'T)0!2`X0)L?\CP
M%']HXGA]'D`45YSP/E>^*#Y]6^)X?\CP%'SI.!2!`0)T?^?X%']GZGA\_S@4
M5[WP/E??*#Y_F^IX?^?X%'SI0!2!`0)\?4=0%']G\GA]2C@45][P/E?G*#Y_
MN_)X?4HX%'T)0!2`X0*$?0C@%']\^GA]".`45__P/E5<*#Y_V_IX?0C@%'SI
M.!2#@0*,?.?H%']]4GA\Y^@454KP/E4=*#Y_^U)X?.?H%'^IX!2#@0*4?]WP
M%']]0GA_WN@450CP/E3]*#Y_WN@4?5U">'TIX!1]*?@4?[\Z>'TI^!17WR@^
M?2GX%%3G\#X[X```?2D`%'UK\!1\YS`4?0@@%'U**!20XP`4D^,``)$C``23
MXP`(D6,`#)/C`!"3XP`8D0,`')/C`""10P`D@4$"G(#BC_A]2CIY..```$""
M`#"``0+$@R$"I(-!`JB#80*L?`@#IH.!`K"#H0*T@\$"N(/A`KPX(0+`3H``
M($@`)>U@````8````"P#``!!@@$PE"'_T#T@$`)\"`*FDV$`'(-I`2"0`0`T
MDT$`&"^;``"3@0`@DZ$`))/!`"B3X0`L09X`B(DC```OB0``09X`Z"N)`#T[
MP```09X`('Q^&WB-/@`!+HD``"N)`#U!E@`(0)[_\'_#\%"#^P``+Y\``$&>
M`$A\FB-X?'P;>']]VWA@````8````'_C^WA_Q?-X?X3C>$@`*"4O@P``0)X`
M$'T_\*XOB0`]09X`0(?]``0OGP``0)[_U(`!`#2#00`8.&```(-A`!R#@0`@
M?`@#IH.A`"2#P0`H@^$`+#@A`#!.@``@8````'^[Z%`X?@`!?[T6<'Q_&A23
MN@``@`$`-(-!`!B#80`<@X$`('P(`Z:#H0`D@\$`*(/A`"PX(0`P3H``(#O`
M``!+__]`.&```$Z``"!@````E"'_T'P(`J:3P0`HD^$`+)`!`#1\?QMX/\`0
M`H$BC_B1(0`<.2```#B!`!A_X_MX3,8Q@DO__HTO@P``09X`3(%!`!B!'@$@
M54H0.GTH4A2$Z0`$+X<``'SH42Y!GO_,A4D`!"^*``"12?_\0)[_]#B!`!A_
MX_MX3,8Q@DO__D4O@P``0)[_O(%!`!R!(H_X?4I*>3D@``!`@@`<@`$`-(/!
M`"B#X0`L."$`,'P(`Z9.@``@2``C[6````!@````E"'_P'P(`J:3@0`PD`$`
M1).A`#23P0`XD^$`/),!`""3(0`DDT$`*)-A`"Q\?QMXB20``&DI`#TA*0``
M@2*/^)$A`!PY(```?Z0!E'^CZWA(`"3A.($`&'Q\&WA_X_MX3,8Q@DO__9U\
M?AMY08(!=$@`),%_G!A`0)T!.(-A`!@_0!`"5WL0.HD_```OB0``09X"!"N)
M`#U!G@'\?^/[>$@``!A@````8````&`````KB0`]09X`$(TC``$OB0``0)[_
M\'Q_&%`[G``"@]H!('Q\&A1(`"/M+X,``'Q^V2Y!G@'(B3\``(%!`!B!&@$@
M54H0.B^)``!]2%`NF2H``$&>`#@KB0`]09X`,'_C^WA(```88````&````!@
M````*XD`/4&>`!2-(P`!G2H``2^)``!`GO_L.2``/3A]__^9*@``8````&``
M``!@````C2,``9TJ``$OB0``0)[_]#A@``"!00`<@2*/^'U*2GDY(```0((!
M/(`!`$2#`0`@@R$`)(-!`"A\"`.F@V$`+(.!`#"#H0`T@\$`.(/A`#PX(0!`
M3H``(&````!@````.'W__SE>__]@````8````(TC``&=*@`!+XD``$">__1+
M__^08````&````!@````/T`0`H,:`2"!.```+XD``$&>`*Q_",-X.4```$@`
M``A_RO-XA2@`!#O*``$OB0``0)[_\#E*``-51!`Z/4`0`H$J`40OB0``09X`
M.'\#PWA(`"*!+X,``)!Z`2!!G@!L5]L0.CD^``$Y0```52D0.GU#22Z3P0`8
M2__^,&`````Y(``!?(,C>)$J`41(`")5?'D;>4&"`#17VQ`Z?P3#>']EVWA(
M`"#=DSH!('\CRWA+__^T.&```$O__C`X@``(.\```$O__W@X8/__2__^N$@`
M(3%@````8````&````"4(?]@?`@"II.A`)20`0"DDV$`C).!`)"3P0"8D^$`
MG'Q]&WF!(H_XD2$`?#D@``!!@@`0B3T``"^)``!`G@!$@4$`?($BC_A]2DIY
M.2```$""`5B``0"D@V$`C(.!`)"#H0"4?`@#IH/!`)B#X0"<."$`H$Z``"!@
M````8````$@`(^%\?AMY08+_N#]@$``[>T^<8````&````!@````?\/S>$@`
M(TTL`P``08(`I(DC`!,OB0`N09X`N#OC`!-_H^MX2``AK7Q\&WA_X_MX2``A
MH7Q\&A0X8P`"2``A)7_H^WA_I^MX?V;;>#B@__]\?!MX.(```4S&,8)(`"&E
M.*$`$'^$XW@X8``#2``C!2^#__]_@^-X09X`%($A`"!5*00F*XE``$&>`'A(
M`"`5?X/C>$@`'WU_P_-X2``BM2P#``!`@O]L8````&````!_P_-X2``B_7^C
MZWA(`!^52__^X&````!@````8````(DC`!0OB0``09[_*"N)`"Y`GO\\B2,`
M%2^)``!!GO\42___+&````!@````8````$O__F%+__^,2``?>6````"4(?_@
M?`@"II/A`!P_X!`"D\$`&'Q^&WB`?P$HD`$`)$@`(E%_Q/-X.*,!2#A@``-(
M`")1+X,``$&>`"B``0`D@\$`&#A@``"#X0`<."$`('P(`Z9.@``@8````&``
M``"`?P$H2``B#8$C`5A5*00F*XE``$&>`""`?P$H2``A]8$C`5A5*00F;2K_
M_R^*H`!`GO^L?\/S>#B```)(`"%%@`$`)(/!`!B#X0`<."$`('P(`Z9\8P`T
M5&/9?DZ``""4(>_0.*`/_WP(`J:3H1`DD\$0*)`!$#23X1`L?'X;>#Q@$`!\
MG2-X.&-/I#B!`!R!(H_XD2$0'#D@``!(`![%+`,``$"!`)P[X___.4$0('TJ
M^A2)*>_\+XD``$&>`'1\?QMX?^7[>#B``"\X80`<2``@02^#``!!G@!H/2`0
M`H!I`2A(`"$M?^;[>#BA`!Q_Q/-X2``@S8$A$!R!0H_X?2E2>3E```!`@@!4
M@`$0-(.A$"2#P1`H@^$0+#@A$#!\"`.F3H``(&````!@````+Y\``$">_Y!@
M````8````#T@$`*`:0$H2``@R7^EZWA_Q/-X2``>'4O__Z!(`!VUE"'_\#T@
M$`)\"`*F@&D!*)`!`!1(`""=@`$`%#S`$``\H!``/(`0`'P(`Z8XQD\@.*5*
M$#B$3[0X(0`02``?%)0A_^!\"`*FD^$`'#_@$`*`?P$HD`$`)$@`(%E+__^E
M@'\!*$@`($V``0`D/.`0`(/A`!P\H!``..=2K#R`$`!\"`.F.0```'SF.W@X
MI4+P.(1/T#@A`"!(`!]X8````)0AW]!\"`*FD\$@*)`!(#23X2`L@2*/^)$A
M(!PY(```2``=H3T`$``\P!``?&<;>#D(3^@XQD_L.*`0`3B```$X80`43,8Q
M@D@`'DDO@P``09P`<#B@$``X@1`8.&$`%$@`'0%\?AMY08``6#A^``%(`!V!
M?'\;>4&"`$A_Q?-X.($0&$@`'"TY(```?^/[>'T_\:Z!02`<@2*/^'U*2GDY
M(```0((`)(`!(#2#P2`H@^$@+#@A(#!\"`.F3H``(#A@``!+___02``<26``
M``"4(?_P."$`$$O__RA@````E"'OL'V``"9\"`*FDV$0/).A$$20`1!4D^$0
M3)&!$""2H1`DDL$0*)+A$"R3`1`PDR$0-)-!$#B3@1!`D\$02'Q]&W@\8!``
M?)\C>#AC3_PX@0`8@2*/^)$A$!PY(```3,8Q@DO_]>TX@``O?'L;>'^CZWA(
M`!SM+X,``$&>`'0\8!``?Z3K>#AC4`A,QC&"2__WP7^CZWB!01`<@2*/^'U*
M2GDY(```0((!W(`!$%2!@1`@@J$0)(+!$"A\"`.F@N$0+(,!$#!]@($@@R$0
M-(-!$#B#81`\@X$00(.A$$2#P1!(@^$03#@A$%!.@``@?Z/K>#^`$`!(`!R)
M.YQ0&"X;``!_A.-X?'D;>'_C^WA(`!VA?'X;>4&"_V@^X!``/P`0`#J@```^
MP!``.SD``3KW4!P[&%`@/T`0`F*U@``[X```8````&````!@````B3X``"^)
M``!`G@`(.]9/^$&2`!A_Q/-X?V/;>$@`&A4O@P``09X`S'_#\WA(`!P%?5X:
M%(DJ__\OB0`O0)X`*&````!@````8````&````"?ZO__.&/__XDJ__\OB0`O
M09[_\'QY&A0O@P__09W^Q'^IZWA^Z+MX?\?S>'\&PW@XH!``.(```3AA`!Q,
MQC&"2``;T8!Z`2A(`!U).($`'#BC`4@X8``#2``=*2^#``!`G@`<@'H!*$@`
M'2F!(P%852D$)G^)J`!!G@`X?X3C>#A@``!(`!R-?'X;>"^>``!`GO\@2__^
M3&````!@````?X3C>$@`'&U\?AMX2___X#B```$X80`<2``<22^#``!`GO^\
M/&`0`#B!`!PX8U`(3,8Q@DO_]=TX80`<2``;A4O__AA(`!FM8````&````"4
M(?_PB2,``"^)``!!G@!`.4,``4@``!Q@````8````(DJ```Y2@`!+XD``$&>
M`"`KB0`O0)[_[(DJ``!]0U-X.4H``2^)``!`GO_H."$`$$Z``"!@````8```
M`&````"4(?_@?`@"II/A`!Q\?QMYD`$`))/!`!A!@@"(B]\``"^>``!!G@!\
M2``::3AC__]\OQH4?Y\H0$"<`.Q]/QBN+XD`+T">`*Q]/RA0?2D#ID@``!Q@
M````8````&````"))0``+XD`+T">`(@XI?__0@#_\"N>`"]!G@`H@`$`)(/!
M`!@\8!``@^$`'#AC4!Q\"`.F."$`($@`&GA@````.&```D@`&7TL`P``08(`
M)#D@+@"Q(P``@`$`)(/!`!B#X0`<."$`('P(`Z9.@``@@`$`)(/!`!@X8```
M@^$`'#@A`"!\"`.F3H``(&`````Y)?__?Y](0'T_*%!]*0.F09T`L"^?__]`
MO@`42```I(DE```OB0`O09X`%#BE__]"`/_P?Y\H0$&^_TPY)?__?Y](0'T_
M*%!]*0.F09T`@"^?__]`O@`82```=&````"))0``+XD`+T">``PXI?__0@#_
M\'R_*%`Y)0`"*XD0`$&=_V`\8!`"?^3[>#AC`40XP!``.\,`!#BE``%_P_-X
M2``9X8`!`"1_P_-X@^$`'(/!`!@X(0`@?`@#IDZ``"`Y(``!?2D#IDO__V0Y
M(``!?2D#IDO__YA@````8````)0A_[`\@!``?`@"ICB$3R`XH``B.(0`#)`!
M`%23@0!`DZ$`1)/!`$B3X0!,.&$`&#_@$``_P!``._]04#O>3_P_@!``/Z`0
M`#N<4&P[O5!X@2*/^)$A`#PY(```2``6M3Q@$``X8U`H3,8Q@DO_\F4\8!``
M.&-0-$S&,8)+__)5/&`0`#AC4#Q,QC&"2__R13Q@$``X8U!(3,8Q@DO_\C5_
MX_MX3,8Q@DO_\BD\8!``.&-08$S&,8)+__(9?\/S>$S&,8)+__(-?X/C>$S&
M,8)+__(!?Z/K>$S&,8)+__'U/&`0`#AC4(1,QC&"2__QY3Q@$``X8U`(3,8Q
M@DO_\=4\8!``.&-0D$S&,8)+__'%/&`0`#AC4)Q,QC&"2__QM3Q@$``X@0`4
M.&-0J$S&,8)+__!A?&0;>4&"`!!_H^MX3,8Q@DO_\DT\8!``.($`%#AC4+Q,
MQC&"2__P.7QD&WE!@@`4/&`0`#AC4-!,QC&"2__R(3Q@$``X@0`4.&-0W$S&
M,8)+__`-?&0;>4&"`&1_P_-X3,8Q@DO_\?D\@!``?^/[>#B$40Q,QC&"2__Q
MY8%!`#R!(H_X?4I*>3D@``!`@@"$@`$`5(.!`$"#H0!$@\$`2'P(`Z:#X0!,
M."$`4$Z``"!@````8````&`````\8!``.($`%#AC4.Q,QC&"2__OD7QD&WE!
M@@`8?X/C>$S&,8)+__%]2___A&`````\@!``.*``"CB$40`X80`I2``8(2^#
M``!`GO]D.($`,TO__\Q(`!4M8````&````"4(?_0?`@"II/A`"R0`0`T/^`0
M`H!_`0PO@___@2*/^)$A`!PY(```09X`.(%!`!R!(H_X?4I*>3D@``!`@@!P
M@`$`-(/A`"PX(0`P?`@#IDZ``"!@````8````&`````\8!``.($`&#AC4&Q,
MQC&"2__NT2P#``!!@@`HB2,``#A@```OB0``09X`$&DC`#`Q(___?&D9$)!_
M`0Q+__^0.&```)!_`0Q+__^$2``4=90A__!\"`*FD`$`%$@`%'5(`!/1+`,`
M`$&"`!B`8P``@`$`%#@A`!!\"`.F3H``(#A@``!+___L8````&````"4(?^@
M/2`0`'P(`J8Y*4\@@4D`,(")`#2`J0`X@,D`/(#I`$"!"0!$D^$`7)`!`&23
M(0!$DT$`2)-A`$R3@0!0DZ$`5)/!`%B!*0!(?5]3>8%BC_B180`\.6```)%!
M`""0@0`DD*$`*)#!`"R0X0`PD0$`-)$A`#A!@@"`/0`0`#S`$`!\?!MX.\$`
M(#M(4!@[9E`@2```)&````!@````2``2T2^#``!!G@"8A_X`!"^?``!!G@!$
M.($`''_C^WA,QC&"2__MC7^$XWA\?1MY08(`$(E=```OB@``0)[_Q'_C^WA,
MQC&"2__O:8?^``0OGP``0)[_Q($A`#R!0H_X?2E2>3E```!`@@"0@`$`9(,A
M`$2#00!(@V$`3'P(`Z:#@0!0@Z$`5(/!`%B#X0!<."$`8$Z``"!@````8```
M`'^#XWA(`!0]?'D;>'^CZWA(`!0Q?'D:%#AC``)(`!.U?ZGK>'](TWA_A^-X
M?V;;>'QY&W@XH/__.(```4S&,8)(`!0Q?R3+>'_C^WA,QC&"2__NP4O__UA(
M`!*98````#P`__]\+`MX8`!^L#T@$`!\(0%N?`@"ICDI3R"!:0!@@*D`9(#)
M`&B`Z0!L@0D`<(%)`'20#``$@`D`7),,_^"33/_HDVS_[).,__"3K/_TD\S_
M^)/L__R2;/_,DHS_T)*L_]22S/_8DNS_W),L_^0_H!``@^D`6(-)`$R#R0!4
M.[U/_'Q[&WB#B0!0@2D`>#B!`!1_H^MX/P$``8,BC_B3.($,.R```)-!`!B3
M@0`<D^$`,)/!`""0`0`TD6$`.)"A`#R0P0!`D.$`1)$!`"2100`HD2$`+$S&
M,8)+_^O5?'\;>4&"`!")/P``+XD``$">!/!+__TM.^$`(#N!`!1\?AMY08("
M;'_#\WA(`!+55&,(/#AC``%(`!)9B/X``"^'``!\?!MX09X`0#]`$`!\?QMX
M.UI1&&````!@````?^/[>']&TW@XH/__.(```4S&,8)(`!*]C/X``3O_``(O
MAP``0)[_W#OA@1`[00`4A']_("^#``!`G@`42```5(1_``0O@P``09X`2']$
MTWA,QC&"2__K'7Q^&WE!@O_DB3X``"^)``!!GO_82__Q=2^#``!!GO_,?\/S
M>$@`$J5\>AMY0((`@&````!@````@^$`&"^?``!!G@'(B3\``#O```$OB0``
M0)X`/$@``;0Y````5\D0.F$(@1!]"`H4?2A*%#TI__^#Z7\(+Y\``$&>`9")
M/P``.]X``2^)``!!G@&`?^/[>$O_\/DO@P``09[_P'_C^WA(`!(I?'H;>4&"
M_[!_0]-X/P`0`$@`$94[&%`<?'\;>'^#XWA(`!&%?'\:%#OC!`1_X_MX2``1
M!3T@$``\P!``?XKC>#DI42!\>1MX?PC#>']'TW@XQE$H.*#__SB```%,QC&"
M2``1=3B``<!_(\MX2``1J2^#__]!G@$`/\`0`H!^`2A(`!+5?R3+>#BC`4@X
M8``#2``2U2^#``!!G@$</2`0`H#;```\H!``@&D!)'\GRW@XI5&T.(```4S&
M,8)(`!'I.&```#R!``&!!($,@(*/^'T((GDX@```0(((%(%A``"`"P`$@FO_
MS(*+_]""J__4?`@#IH++_]B"Z__<@PO_X(,K_^2#2__H@VO_[(.+__"#J__T
M@\O_^(/K__Q]85MX3H``($@`$0%\?AMY0(+]H&````"$?P`$+X,``$&>`GA_
MA.-X3,8Q@DO_Z2U\:1MY08+_Y(DI```OB0``09[_V$O__\0[0```2__^H&``
M``!@````2``0T8$#```OB``109[^^#T@$`*`VP``/*`0`(!I`21_)\MX.*51
M-#B```%,QC&"2``1`3A@``!+__\88````(!^`2A(`!&=@2,!6%4I!"8KB4``
M0)[^U(!^`2A(`!&%@X,!8$@`#HU_G!@`0)[^O(!^`2A(`!%M@2,!6%4I!?XK
MB0'`0)[^I'_C^WA(``\U.($`%'Q\&W@\8!``.&-3`$S&,8)+_^A=+X,``$&>
M`:2#^P``2``/_7QD&WA_X_MX2__Q\7Q^&WE!@@&(?\/S>$@`#V$O@P`#?'\;
M>$"=`$0X8__\/(`0`#B$47!\?AH42``-02^#``!`G@`H+Y\`!$&>!81__OH4
MB3__^R^)`"]!G@5T8````&````!@````2__XH2^#``!`G@`<.(```'_#\WA,
MQC&"2``/&7QV&WE`@@$8/(`0`#Q@$``XA%$,.&-0;$S&,8)+_^FI2``.-3_`
M$``\P!``.]Y2K'\(PWA\:1MX?\KS>'\GRW@XQE&0.*#__SB```%_@^-X/V`0
M`$S&,8)(``[-.^```#M[4:!(``!48````&````!@````2``/(8$C```OB0`1
M0)X`3$@`#=&3P0`(._\``7_J^WA_",-X?&D;>'\GRWA_9MMX.*#__SB```%_
M@^-X3,8Q@D@`#G$X@`'`?X/C>$@`#J4O@___09[_K'\CRWA(``QE?X3C>'^C
MZWA,QC&"2__HY7^#XWA+__B-?X/C>$O__21+__B!?^/[>$@`#GE+__T4/\`0
M`#A@``T[WE$02__['(/;``!+__YX.*#__SC`_^XXX``"2``-'3B@``8X@0$,
M?L.S>$@`"\V)(0$,+XD``$">`!")(0$-+XD`0T&>!&0XX```.*```#C```!^
MP[-X2``,X3T@9T4Y````82DC`9$!`$B1(0!,/2#OS6$IJXDY````D2$`5#T@
MF+IA*=S^D0$`4)$A`%P](!`R82E4=CD```"1(0!D/2##TF$IX?"1`0!8.0``
M`#E````Y8```D0$`8)$A`&PY````.2```)$!`&B100!PD6$`=)%!`'B180!\
MD2$`P#J@```[00"`.N$`2&````!@````8````#B@```X@0$,8*6``'[#LWA(
M``KQ?'L;>4"!`4"!(0!P@4$`=']H_G`KB0``5VD8.'TI4!1!G0+\0)X`#'^*
M2$!!G0+P@,$`>(#A`'R`80#`5048.%=J'WY\JE-X50@??B^#``!]2C@4?0@Q
M%)*A`'"1(0!TD0$`>)%!`'Q!G@*D(2,`0']TVWA_FT@`0)T`"'TT2WA^A:-X
M.($!#'QZ&A1(``JA@2$`P'TT2A0OB0!`D2$`P$">_TPY00$,?N.[>']TV%!^
MBJ(42__7"6`````OFP`_0)T`4']^VWA^GZ-X?^3[>#B@`$!_0]-X.][_P$@`
M"E%^X[MX._\`0$O_UM4OG@`_09W_W#M[_\!7:=&^'4G_P#DI``%5*3`R?I1*
M%']JVA1_9=MX.,``2'Z$HWA_0]-X2``+;3B@```X@0$,8*6``'[#LWB380#`
M2``)M7Q[&WE!@?[(?L.S>#MA`(!(``UA@^$`=#E`_X"#P0!\5^GNOCAI``%]
M6TFN+X,`.$&=`@0@HP`X.(```'Q[&A1(``O!5\5&/E?&A#Y7Q\(^5^A&/E?J
MA#Y7Z<(^.&$`2)BA`+B8P0"YF.$`NIO!`+N9`0"\F4$`O9DA`+Z;X0"_2__6
M`8$!`%R`H0!,@,$`5(%!`&2!(0!L51J$/E4;PCY57D8^55^$/E2G1CY4LX0^
M5*S"/E341CY4U80^5-;"/E471CY50,(^52M&/E4CA#Y5),(^FT$`U3]`$`";
M80#6F\$`V)OA`-F8X0#,FF$`S9F!`,Z8H0#/FH$`T)JA`-&:P0#2F,$`TYKA
M`-29`0#7F`$`VIE!`-N980#<F&$`W9B!`-Z9(0#?.^$`X#O!`,P[80$(.UI1
M&$@```Q@````C/X``7_C^WA_1M-X.*#__SB```$[_P`"3,8Q@D@`"G5_F_A`
M0)[_W#U`$``\P!``.6```#E*4JPY(0#@?PC#>'\GRW@XQE&`.*#__SB```%_
M@^-XF6$!"$S&,8)(``HU?R/+>$@`"#U_A.-X?Z/K>$S&,8)+_^2]?X/C>$O_
M]&5_@^-X2__X_&````!@````.H$!#$O__:Q@````8````(%!`'R`P0!X,.H`
M`7S&`91+__T,@_L`!"^?``!!GOJ4?^/[>$@`"9TK@P`#0)WZA#AC__P\@!``
M.(11>'Q_&A1(``>!+X,``$">^FA__OMX2__Z8""C`$`X@```?'L:%$@`"<$X
M80!(2__4.3B@`#@X@```?V/;>$@`":E+__WHB2$!#B^)`$%`GON8B2$!#R^)
M`$-`GON,B2$!$"^)`$A`GON`B2$!$2^)`$5`GOMT.,#_QCC@``(XH/__?L.S
M>$@`"%$X@0$,.*``*7[#LWA(``<!/4`0`#S`$``Y2E*L.2$!#'\(PWA_)\MX
M.,91@#B@__\X@``!?X/C>$S&,8)(``CQ2__ZE$@`!VE@````E"'_L'P(`J:3
M`0`PD`$`5)+A`"R3(0`TDT$`.)-A`#R3@0!`DZ$`1)/!`$B3X0!,/P`0`H!X
M`2B!(H_XD2$`'#D@``!(``H=.2```3B!`!B9(P!E/&`0`#AC4%!,QC&"2__A
M(2P#``!!@@`0B2,``"^)`#%!G@)<2__O>8!X`2@_H!`".[T!1$@`"=D\@!``
M.,``"SB@``$XA%((2``'M2P#``!!@@#@@3T0!(%#`!`OB0`!@RH`&$"=`,P_
M8!`"/N``(#O````[X``!.WL!*&+W!`!(```T8````&````"`B``0?T/3>$@`
M!<F!/1`$+X,``$">`(0[_P`!.]X``7^)^`!`G0!T@'L``$@`"54XP```?\7S
M>'\DRWA(``C5?'P;>4&"`?R!'```@/T0"%?J$#J!*``(?T=0+G[I2#@KB00`
M09[_G(![``!(``D5@)P``#C```(XH```2``&=7QD&WA_0]-X2``%28$]$`0O
M@P``09[_A#E)__]_BO``09X!8(!X`2@_P!`"2``(U3R`$``XP``#.*```3B$
M4A!(``:Q?'\;>4&"`#2`?@$H2``(L8$_`!`\H!``.*52%(")``!(``7]@3\`
M$($I``"!*0`(=2H`0$""`ER`>`$H/^`0`D@`"'T\@!``.,```SB@``$XA%(<
M2``&67Q^&WE!@@`X/&`0`#B!`!@X8U`(3,8Q@DO_WVU\?!MY@'\!*$&"`;!(
M``@]@3X`$'^%XWB`B0``2``%C8!X`2A(``@E.2```#B!`!B9(P!E/&`0`#AC
M3_Q,QC&"2__?*2^#``!\?QMXD'T0#$&>`-@X@`'`2``&L2^#`!%!G@`0.2,`
M`2N)``%!G0'<@2$`'(%"C_A]*5)Y.4```$""`<2``0!4@N$`+(,!`#"#(0`T
M?`@#IH-!`#B#80`\@X$`0(.A`$2#P0!(@^$`3#@A`%!.@``@B2,``2^)``!!
MGOVD2__]G"^)``%`G?Z@.^```6````"`>P``._\``4@`!VE_),MX2``$$8$]
M$`1_B?@`09W_Y$O__G1@````8````&````"!/1`$.4G__W^*\`!`GOY82___
ML&````!@````8````(!]$`A+__&-+X,``)!]$`Q!G@#\@3X`$(%)```](``@
M82D$`($*``A]*4`X*XD$`$">`*"`:@`0@_T0"'_D^WA(``0A@3X`$(/_``"!
M20``/2``('Q]&WAA*00`@0H`"'TI0#@KB00`0)X`1("J`!`\8!``?Z;K>'_D
M^W@X8U)$3,8Q@D@`!2U@````8````$@`!I&!71`(@3X`$("*``"`:0``2__D
MS4O__E"`>`$H2``&<8$^`!`XH```.,```H")``!(``/-?&4;>$O__Z0](!`"
M@&D!*$@`!DF!/@`0.,```CB@``"`B0``2``#I4O__TB`?@$H2``&*8$_`!"`
MB0``2``%/4O__90\8!``.&-2($S&,8)(``292``#!8$]$`A\9AMX/&`0`'_E
M^W@X8U)L@(D``$S&,8)(``1UE"'_X'P(`J:3P0`8D^$`')`!`"1\?AMX2__I
MB8DC``!\?QMX+XD``$&>`$0Y0P`!2```(&````!@````8````(DJ```Y2@`!
M+XD``$&>`"`KB0`O0)[_[(DJ``!]7U-X.4H``2^)``!`GO_H2__M52^#``!!
MG@`P+YX``$&>`"B)/@``+XD``$&>`!P\@!``?^/[>#B$42!(``&)?Y\8`$&>
M`!R``0`D@\$`&(/A`!PX(0`@?`@#IDZ``""``0`D@^$`''_#\WB#P0`8."$`
M('P(`Z9+_^#L``````````"4(?_P?`@"ID*?``63P0`(D`$`%'_(`J8_W@`"
M.]XVB($^@``OB0``09X`*(#)``!(``)A@`$`%(/!``@X(0`0?`@#IDZ``"!@
M````8````#C```!(``(]@`$`%(/!``@X(0`0?`@#IDZ``"``````E"'_T'P(
M`J9"GP`%D\$`*),A`!1_R`*FDT$`&)-A`!R3@0`@DZ$`))/A`"R0`0`T?'D;
M>'R:(WA\NRMX/]X``CO@```[WC8<2__)98.>@`2!/H``.[S__'^<2%!_G!9Q
M08(`-&````!@````8````(4]``1_(\MX?T33>']EVWA]*0.F._\``4Z`!"%_
MG^!`0)[_X(`!`#2#(0`4@T$`&(-A`!Q\"`.F@X$`((.A`"2#P0`H@^$`+#@A
M`#!.@``@3H``(````````````````#U@$`*!:P``?6D#IDZ`!"`]8!`"@6L`
M!'UI`Z9.@`0@/6`0`H%K``A]:0.F3H`$(#U@$`*!:P`,?6D#IDZ`!"`]8!`"
M@6L`$'UI`Z9.@`0@/6`0`H%K`!1]:0.F3H`$(#U@$`*!:P`8?6D#IDZ`!"`]
M8!`"@6L`''UI`Z9.@`0@/6`0`H%K`"!]:0.F3H`$(#U@$`*!:P`D?6D#IDZ`
M!"`]8!`"@6L`*'UI`Z9.@`0@/6`0`H%K`"Q]:0.F3H`$(#U@$`*!:P`P?6D#
MIDZ`!"`]8!`"@6L`-'UI`Z9.@`0@/6`0`H%K`#A]:0.F3H`$(#U@$`*!:P`\
M?6D#IDZ`!"`]8!`"@6L`0'UI`Z9.@`0@/6`0`H%K`$1]:0.F3H`$(#U@$`*!
M:P!(?6D#IDZ`!"`]8!`"@6L`3'UI`Z9.@`0@/6`0`H%K`%!]:0.F3H`$(#U@
M$`*!:P!4?6D#IDZ`!"`]8!`"@6L`6'UI`Z9.@`0@/6`0`H%K`%Q]:0.F3H`$
M(#U@$`*!:P!@?6D#IDZ`!"`]8!`"@6L`9'UI`Z9.@`0@/6`0`H%K`&A]:0.F
M3H`$(#U@$`*!:P!L?6D#IDZ`!"`]8!`"@6L`<'UI`Z9.@`0@/6`0`H%K`'1]
M:0.F3H`$(#U@$`*!:P!X?6D#IDZ`!"`]8!`"@6L`?'UI`Z9.@`0@/6`0`H%K
M`(!]:0.F3H`$(#U@$`*!:P"$?6D#IDZ`!"`]8!`"@6L`B'UI`Z9.@`0@/6`0
M`H%K`(Q]:0.F3H`$(#U@$`*!:P"0?6D#IDZ`!"`]8!`"@6L`E'UI`Z9.@`0@
M/6`0`H%K`)A]:0.F3H`$(#U@$`*!:P"<?6D#IDZ`!"`]8!`"@6L`H'UI`Z9.
M@`0@/6`0`H%K`*1]:0.F3H`$(#U@$`*!:P"H?6D#IDZ`!"`]8!`"@6L`K'UI
M`Z9.@`0@/6`0`H%K`+!]:0.F3H`$(#U@$`*!:P"T?6D#IDZ`!"`]8!`"@6L`
MN'UI`Z9.@`0@/6`0`H%K`+Q]:0.F3H`$(#U@$`*!:P#`?6D#IDZ`!"`]8!`"
M@6L`Q'UI`Z9.@`0@/6`0`H%K`,A]:0.F3H`$(#U@$`*!:P#,?6D#IDZ`!"`]
M8!`"@6L`T'UI`Z9.@`0@/6`0`H%K`-1]:0.F3H`$(#U@$`*!:P#8?6D#IDZ`
M!"`]8!`"@6L`W'UI`Z9.@`0@/6`0`H%K`.!]:0.F3H`$(#U@$`*!:P#D?6D#
MIDZ`!"`]8!`"@6L`Z'UI`Z9.@`0@/6`0`H%K`.Q]:0.F3H`$(#U@$`*!:P#P
M?6D#IDZ`!"`]8!`"@6L`]'UI`Z9.@`0@/6`0`H%K`/A]:0.F3H`$(#U@$`*!
M:P#\?6D#IDZ`!"`]8!`"@6L!`'UI`Z9.@`0@2``!`$@``/Q(``#X2```]$@`
M`/!(``#L2```Z$@``.1(``#@2```W$@``-A(``#42```T$@``,Q(``#(2```
MQ$@``,!(``"\2```N$@``+1(``"P2```K$@``*A(``"D2```H$@``)Q(``"8
M2```E$@``)!(``",2```B$@``(1(``"`2```?$@``'A(``!T2```<$@``&Q(
M``!H2```9$@``&!(``!<2```6$@``%1(``!02```3$@``$A(``!$2```0$@`
M`#Q(```X2```-$@``#!(```L2```*$@``"1@````8````&````!@````8```
M`&````!@````8````#V`$`(]:_``@`S_^#EKLF!\"0.F?`M:%(&,__Q]8%H4
M3H`$(&````!@````8````&````!@````8````&````"4(?_P?`@"II`!`!23
MP0`(0I\`!7_(`J:``0`4?`@#IH/!``@X(0`03H``(!`"@1`0`!+`$`!(P!``
M28```@`!<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("``````$`!2X!``4O`0`%+X$`!3`!``4P@0`%,<`````!``4M@0`$_X
M`````!``4-`0`%#4$`!2S!``4``0`%+4`````!``4K@0`%+``````"5S+R5S
M````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4`+W!R;V,O)6DO)7,`+@``
M`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````+P```"5S)7,E<P``
M4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<`
M``!005)?0T%#2$4```!005)?05)'0P````!005)?05)'5E\P``!005)?1TQ/
M0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%.
M/0``,0```%-94U1%30``)3`R>`````!P87(M`````"5S)7,E<R5S`````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``05)'5@`````8````<&5R
M;``````P````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%````
M`%1%35!$25(`5$U0`"]T;7``````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`
M3$E"4D%265]0051(`````$193$1?3$E"4D%265]0051(````4TA,24)?4$%4
M2```979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O
M8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G
M)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E
M86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D
M=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R
M/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I
M"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?
M05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@
M)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q
M*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@
M)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\
M)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY
M("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O
M9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q
M<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@
M/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D
M(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T
M.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@
M)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R
M."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X]
M(#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@
M,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N
M<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE
M("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D
M8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[
M"FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@
M*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN
M960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2![
M"FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I
M.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68[
M"F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]4
M14U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN
M(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*
M96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T
M*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA
M<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M
M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U
M="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*
M?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H
M)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM
M>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL
M7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF
M>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I
M('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`
M05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D
M9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2![
M"G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*
M979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D
M,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*
M96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@
M*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I
M('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@
M;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`[
M"FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B
M0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z
M("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D
M(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!
M4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D
M92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S
M(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R
M(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO
M861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!
M4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL
M97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R
M:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F
M:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X
M="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I
M9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE
M;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N
M86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@
M*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````0`!80$``5T```
M```0`@$($`'^W!`!_M@````!`````0````$```'3`````0```B(````,$``2
M;`````T0`$[@````&1`!_M@````;````!````!H0`?[<````'`````1O__[U
M$``!B`````40``CL````!A```HP````*```$SP````L````0````%0``````
M```#$`(```````(```,,````%`````<````7$``/8'`````0`?_T````!Q``
M#Q@````(```#5`````D````,;____A``#HAO____`````F____`0``V\````
M````````````````````````````````````````````````````````````
M`````!`!_O```````````!``3:`0`$VD$`!-J!``3:P0`$VP$`!-M!``3;@0
M`$V\$`!-P!``3<00`$W($`!-S!``3=`0`$W4$`!-V!``3=P0`$W@$`!-Y!``
M3>@0`$WL$`!-\!``3?00`$WX$`!-_!``3@`0`$X$$`!."!``3@P0`$X0$`!.
M%!``3A@0`$X<$`!.(!``3B00`$XH$`!.+!``3C`0`$XT$`!..!``3CP0`$Y`
M$`!.1!``3D@0`$Y,$`!.4!``3E00`$Y8$`!.7!``3F`0`$YD$`!.:!``3FP0
M`$YP$`!.=!``3G@0`$Y\$`!.@!``3H00`$Z($`!.C!``3I`0`$Z4$`!.F!``
M3IP0`$Z@``````````#_____$`!3*$=#0SH@*%5B=6YT=2`U+C,N,2TV=6)U
M;G1U,2D@-2XS+C$@,C`Q-C`Q,30`1T-#.B`H56)U;G1U(#0N.2XS+3AU8G5N
M='4R*2`T+CDN,P``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N
M;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A
M<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YG;W0R`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+G-D871A`"YB<W,`+F-O;6UE;G0`````````````````````````````
M``````````````````````````````````L````!`````A```30```$T````
M#0```````````````0`````````3````!P````(0``%$```!1````"``````
M``````````0`````````(0````<````"$``!9````60````D````````````
M```$`````````#1O___V`````A```8@```&(```!!`````4`````````!```
M``0````^````"P````(0``*,```"C```!F`````&`````0````0````0````
M1@````,````"$``([```".P```3/```````````````!`````````$YO____
M`````A``#;P```V\````S`````4``````````@````(```!;;____@````(0
M``Z(```.B````)`````&`````@````0`````````:@````0````"$``/&```
M#Q@```!(````!0`````````$````#````'0````$````0A``#V````]@```#
M#`````4````6````!`````P```!^`````0````80`!)L```2;````$0`````
M``````````0`````````A`````$````&$``2P```$L```#P@````````````
M```@`````````(H````!````!A``3N```$[@````+```````````````!```
M``````"0`````0````(0`$\,``!/#```0=````````````````0`````````
MF`````$````"$`"0W```D-P````$```````````````$`````````*(````.
M`````Q`!_M@``/[8````!```````````````!`````````"N````#P````,0
M`?[<``#^W`````0```````````````0`````````N@````$````#$`'^X```
M_N`````$```````````````$`````````+\````!`````Q`!_N0``/[D````
M#````````````````0````````#%````!@````,0`?[P``#^\````0`````&
M``````````0````(````S@````$````#$`'_\```__`````0````````````
M```$````!````'D````!`````Q`"`````0`````!!```````````````!```
M``````#3`````0````,0`@$$``$!!`````P```````````````0`````````
MV0````$````#$`(!$``!`1`````$```````````````$`````````.`````(
M`````Q`"`2```0$4```0.```````````````$`````````#E`````0```#``
M``````$!%````$\```````````````$````!`````0````,````````````!
6`6,```#N```````````````!````````
